pub enum LocationError {
PermissionDenied,
PositionUnavailable,
Timeout,
ServerError,
}Expand description
Errors that can be returned by __location__.
Variants
PermissionDenied
The user denied the browser’s location permission prompt
(GeolocationPositionError.PERMISSION_DENIED, code 1).
The device could not determine its position
(GeolocationPositionError.POSITION_UNAVAILABLE, code 2).
Timeout
The browser did not obtain a fix within its internal 30 s timeout
(GeolocationPositionError.TIMEOUT, code 3).
ServerError
The local HTTP server or the Tokio runtime could not be started.