Re-exports all backend dependencies used by the serialization module.
serialization
Only available when the backend-deps feature is enabled together with the serialization feature.
backend-deps
pub use bincode;
pub use base64;
pub use zeroize;