Re-exports all backend dependencies used by the socket module and its
sub-modules (server, client).
Only available when the backend-deps feature is enabled together with at
least one of socket-server or socket-client.
Re-exports all backend dependencies used by the socket module and its
sub-modules (server, client).
Only available when the backend-deps feature is enabled together with at
least one of socket-server or socket-client.