pub struct StatefulJsonSocketBuilder<T, S> { /* private fields */ }Expand description
Route builder that carries shared state S and expects a JSON body of type T.
Obtained from JsonSocketBuilder::state or StatefulSocketBuilder::json.
Implementations
Sourceimpl<T: DeserializeOwned + Send + 'static, S: Clone + Send + Sync + 'static> StatefulJsonSocketBuilder<T, S>
impl<T: DeserializeOwned + Send + 'static, S: Clone + Send + Sync + 'static> StatefulJsonSocketBuilder<T, S>
Sourcepub fn onconnect<F, Fut, Re>(self, handler: F) -> SocketType
pub fn onconnect<F, Fut, Re>(self, handler: F) -> SocketType
Finalises this route with an async handler that receives (state: S, body: T).
Sourcepub unsafe fn onconnect_sync<F, Re>(self, handler: F) -> SocketType
pub unsafe fn onconnect_sync<F, Re>(self, handler: F) -> SocketType
Finalises this route with a synchronous handler that receives (state: S, body: T).
Safety
See ServerMechanism::onconnect_sync for the thread-pool safety notes.