Module backend_deps

Module backend_deps 

Re-exports all backend dependencies used by the serialization module.

Only available when the backend-deps feature is enabled together with the serialization feature.

Re-exports

pub use bincode;
pub use base64;