pub struct ServerFuture(/* private fields */);Expand description
Opaque future returned by Server::serve, Server::serve_with_graceful_shutdown,
and Server::serve_from_listener.
A ServerFuture can be used in two ways:
.await— drives the server inline in the current task..background()— spawns the server on a new Tokio task and returns atokio::task::JoinHandle<()>immediately.
Implementations
Sourceimpl ServerFuture
impl ServerFuture
Sourcepub fn background(self) -> JoinHandle<()>
pub fn background(self) -> JoinHandle<()>
Spawns the server on a new Tokio background task and returns a JoinHandle<()>.
Panics
Panics if called outside a Tokio runtime.