pub trait Reply: Send {
// Required method
fn into_response(self) -> Response<Bytes>;
}Expand description
A value that can be converted into a fully-formed HTTP response.
Implemented for all types returned by the [reply!] macro and the standalone
reply helpers. You may also implement it for your own types.
Required Methods
Sourcefn into_response(self) -> Response<Bytes>
fn into_response(self) -> Response<Bytes>
Consumes self and returns a complete HTTP response.